@@ -1,3 +1,18 @@
+/*
+
+desktop-cmd-exec.c - Desktop Command Execution Widget
+
+Copyright (c) 2010 cpscotti (Clovis Peruchi Scotti)
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+[cpscotti, roboscotti, scotti@ieee.org]
+
+*/
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -9,6 +24,8 @@
 #include <libintl.h>
 #include <stdlib.h>
 
+#include <conic.h>
+
 #define HOME_DIR g_get_home_dir()
 
 #define _(String) dgettext("hildon-libs", String)
@@ -24,6 +41,10 @@
 #define NON_GTK_RESPONSE_DELETE_CMD 30
 //save is GTK_RESPONSE_OK
 
+#define NETWORK__UNRELATED 0
+#define NETWORK__ONLY_CONNECTED 1
+#define NETWORK__ONLY_DISCONNECTED 2
+
 void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset);
 gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self);
 
@@ -58,12 +79,18 @@ struct _DesktopCmdExecPrivate
 	gboolean updOnClick;
 	gboolean updOnDesktop;
 
+	guint updNeworkPolicy;
+
 	//Update on timer data
 	guint delaySeconds;
 	guint delayIndex;//index of delaySeconds in the array defined inside "desktop_cmd_exec_settings"
 
 	//timer process id; used to stop when closing app or changing delay
 	guint updateTimerID;
+
+	//network connection query ptr
+	ConIcConnection *connection;
+	gboolean isConnected;
 };
 
 HD_DEFINE_PLUGIN_MODULE (DesktopCmdExec, desktop_cmd_exec, HD_TYPE_HOME_PLUGIN_ITEM);
@@ -145,6 +172,17 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 		}
 		else
 			self->priv->delaySeconds = GetSeconds(self->priv->delayIndex);
+
+		self->priv->updNeworkPolicy = (guint) g_key_file_get_integer (keyFile, "config", "updNeworkPolicy", &error);
+		if (error || self->priv->updNeworkPolicy < 0 || self->priv->updNeworkPolicy > 2) {
+			//Not important; in order not to break with older key-file versions, just assume NETWORK__UNRELATED and move on..
+			self->priv->updNeworkPolicy = NETWORK__UNRELATED;
+			
+			g_error_free (error);
+			error = NULL;
+		}
+
+		
 		
 		//END
 		g_key_file_free (keyFile);
@@ -204,6 +242,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset)
 
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
+		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 		self->priv->delayIndex = 0;
 		
 // 		g_warning("Diiiiid it");
@@ -216,6 +255,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean reset)
 	g_key_file_set_boolean (keyFile, "config", "updOnClick", self->priv->updOnClick);
 	g_key_file_set_boolean (keyFile, "config", "updOnDesktop", self->priv->updOnDesktop);
 	g_key_file_set_integer (keyFile, "config", "delayIndex", self->priv->delayIndex);
+	g_key_file_set_integer (keyFile, "config", "updNeworkPolicy", self->priv->updNeworkPolicy);
 	
 	filename = g_strconcat (HOME_DIR, "/.desktop_cmd_exec", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -269,6 +309,23 @@ static void desktop_cmd_exec_check_desktop (GObject *gobject, GParamSpec *pspec,
 }
 
 
+gboolean desktop_cmd_exec_connection_event (ConIcConnection *connection, ConIcConnectionEvent *event, DesktopCmdExec *self)
+{
+	ConIcConnectionStatus status = con_ic_connection_event_get_status(event);
+	if(status == CON_IC_STATUS_CONNECTED)
+	{
+		self->priv->isConnected = TRUE;
+	}
+	else
+	{
+		self->priv->isConnected = FALSE;
+	}
+
+
+	desktop_cmd_exec_update_content(self);
+	return TRUE;
+}
+
 
 //Content/widget creation/update
 void desktop_cmd_exec_content_create (DesktopCmdExec *self)
@@ -312,6 +369,14 @@ void desktop_cmd_exec_content_create (DesktopCmdExec *self)
 gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 {
 // 	g_warning ("desktop_cmd_exec_update_content");
+
+	if(self->priv->updNeworkPolicy == NETWORK__ONLY_CONNECTED && self->priv->isConnected == FALSE)
+		return TRUE;
+	
+	if(self->priv->updNeworkPolicy == NETWORK__ONLY_DISCONNECTED && self->priv->isConnected == TRUE)
+		return FALSE;
+
+
 	FILE *fp;
 	gchar line[256];
 	gchar *result;
@@ -368,6 +433,8 @@ static void desktop_cmd_exec_finalize (GObject *object)
 		g_source_remove (self->priv->updateTimerID);
 	}
 
+	g_object_unref (self->priv->connection);
+
 	g_strfreev(self->priv->c_titles);
 	g_strfreev(self->priv->c_commands);
 
@@ -461,6 +528,14 @@ static void desktop_cmd_exec_init (DesktopCmdExec *self)
 	self->priv = DESKTOP_CMD_EXEC_GET_PRIVATE (self);
 	self->priv->updateTimerID = 0;
 	self->priv->isPressed = FALSE;
+
+
+	self->priv->connection = con_ic_connection_new ();
+	g_signal_connect (self->priv->connection, "connection-event", G_CALLBACK (desktop_cmd_exec_connection_event), self);
+	g_object_set (self->priv->connection, "automatic-connection-events", TRUE);
+	self->priv->isConnected = FALSE;
+
+	self->priv->cmdResult_lb = NULL;
 	
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (desktop_cmd_exec_settings), self);
@@ -509,13 +584,25 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 																										 "Edit Cmd", NON_GTK_RESPONSE_EDIT_CMD,
 																										 NULL);
 
-		GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+// 		GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+
+		GtkWidget *settingsArea = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		GtkWidget *scroll = hildon_pannable_area_new ();
+		g_object_set (scroll, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
+		GtkWidget *content_area = gtk_vbox_new (FALSE, 0);
+		hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (scroll), content_area);
+		gtk_container_add (GTK_CONTAINER (settingsArea), scroll);
+		gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 380);
+
+
 		GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
 		GtkWidget *cmdSelectionLabel = gtk_label_new ("");
 		gtk_label_set_markup (GTK_LABEL (cmdSelectionLabel), "<small>Command Selection:</small>");
 		gtk_container_add (GTK_CONTAINER (content_area), cmdSelectionLabel);
-
+		
+		
 		//BEGIN Command Selector
 		
 		GtkWidget *selector = hildon_touch_selector_new_text ();
@@ -574,6 +661,22 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		GtkWidget *updIntervalLabel = gtk_label_new ("");
 		gtk_label_set_markup (GTK_LABEL (updIntervalLabel), "<small>'0' disables periodic updating</small>");
 		gtk_container_add (GTK_CONTAINER (content_area), updIntervalLabel);
+
+
+		GtkWidget *networkPolicySel = hildon_touch_selector_new_text ();
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Doesn't Matter");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Only when connected");
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (networkPolicySel), "Only when disconnected");
+		hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (networkPolicySel), 0, self->priv->updNeworkPolicy);
+		
+		GtkWidget * networkPolBt = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
+		hildon_button_set_title (HILDON_BUTTON (networkPolBt), "Network Presence: ");
+		hildon_button_add_title_size_group (HILDON_BUTTON (networkPolBt), group);
+		hildon_button_set_alignment (HILDON_BUTTON (networkPolBt), 0, 0.5, 0, 0);
+		hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (networkPolBt), HILDON_TOUCH_SELECTOR (networkPolicySel));
+		gtk_container_add (GTK_CONTAINER (content_area), networkPolBt);
+		
+		
 		//END
 
 		gtk_widget_show_all (dialog);
@@ -595,6 +698,8 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 			
 			self->priv->delayIndex = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (intervalSelector), 0);
 			self->priv->delaySeconds = GetSeconds(self->priv->delayIndex);
+
+			self->priv->updNeworkPolicy = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (networkPolicySel), 0);
 			
 			if (self->priv->updateTimerID != 0) {
 				g_source_remove (self->priv->updateTimerID);
